@@ -10,7 +10,7 @@ use AnyEvent::Open3::Simple::Process;
 use Carp qw( croak );
 
 # ABSTRACT: interface to open3 under AnyEvent
-our $VERSION = '0.69_01'; # VERSION
+our $VERSION = '0.69_02'; # VERSION
 
 
 sub new
@@ -169,7 +169,7 @@ AnyEvent::Open3::Simple - interface to open3 under AnyEvent
 
 =head1 VERSION
 
-version 0.69_01
+version 0.69_02
 
 =head1 SYNOPSIS
 
@@ -344,6 +344,11 @@ attribute to force it use an idle watcher instead.  Patches for detecting
 environments where idle watchers should be used are welcome and
 encouraged.
 
+The pure perl implementation that comes with Perl
+(L<AnyEvent::Impl::Perl>) does not seem to work with this module
+on Microsoft Windows so I make L<EV> a prereq on that platform 
+(which does work).
+
 Writing to a subprocesses stdin via L<AnyEvent::Open3::Simple::Process>'s
 C<print> method is unsupported on Microsoft Windows (it does work under
 Cygwin though).
